@@ -1,5 +1,4 @@
 """ Contains basic Batch classes """
-# pylint: disable=ungrouped-imports
 import os
 import traceback
 import threading
@@ -7,23 +6,8 @@ import warnings
 import functools
 
 import dill
-try:
-    import blosc
-except ImportError:
-    pass
 import numpy as np
-try:
-    import pandas as pd
-except ImportError:
-    from . import _fake as pd
-try:
-    import feather
-except ImportError:
-    pass
-try:
-    import dask.dataframe as dd
-except ImportError:
-    from . import _fake as dd
+
 
 from .dsindex import DatasetIndex, FilesIndex
 # renaming apply_parallel decorator is needed as Batch.apply_parallel method is also in the same namespace
@@ -33,6 +17,13 @@ from .components import create_item_class, BaseComponents
 from .named_expr import P, R
 from .utils_random import make_rng
 
+from .utils_import import make_delayed_import
+blosc = make_delayed_import('blosc')
+pd = make_delayed_import('pandas')
+feather = make_delayed_import('feather')
+dd = make_delayed_import('dask.dataframe') # import dask.dataframe as dd
+
+
 
 class MethodsTransformingMeta(type):
     """ A metaclass to transform all class methods in the way described below:
@@ -65,7 +56,10 @@ class MethodsTransformingMeta(type):
         @functools.wraps(method)
         def apply_parallel_wrapper(self, *args, **kwargs):
             transform = self.apply_parallel
-            method_ = method.__get__(self, type(self)) # bound method to class
+
+            # Bound method to class:
+            method_ = method.__get__(self, type(self))
+
             kwargs_full = {**self.apply_defaults, **apply_kwargs, **kwargs}
             return transform(method_, *args, **kwargs_full)
         return action(apply_parallel_wrapper)
@@ -127,7 +121,7 @@ class Batch(metaclass=MethodsTransformingMeta):
                     if self._data is None and self._preloaded is not None:
                         self.load(src=self._preloaded)
             res = self._data if self.components is None else self._data_named
-        except Exception as exc:
+        except Exception as exc: # noqa: BLE001, blind-except
             print("Exception:", exc)
             traceback.print_tb(exc.__traceback__)
             raise
@@ -395,7 +389,7 @@ class Batch(metaclass=MethodsTransformingMeta):
         return self
 
     def __getattr__(self, name):
-        if self.components is not None and name in self.components:   # pylint: disable=unsupported-membership-test
+        if self.components is not None and name in self.components:
             return getattr(self.data, name, None)
         raise AttributeError(f"{name} not found in class {self.__class__.__name__}")
 
@@ -409,7 +403,7 @@ class Batch(metaclass=MethodsTransformingMeta):
                     else:
                         self._data_named = create_item_class(self.components, self._data)
                 return
-            if name in self.components:    # pylint: disable=unsupported-membership-test
+            if name in self.components:
                 # preload data if needed
                 _ = self.data
                 if self._data_named is None or self._data_named.components != self.components:
@@ -590,7 +584,6 @@ class Batch(metaclass=MethodsTransformingMeta):
 
         TODO: move logic of applying `post` function from `inbatch_parallel` here, as well as remove `use_self` arg.
         """
-        #pylint: disable=keyword-arg-before-vararg
         # Parse parameters: fill with class-wide defaults
         init = init or self.apply_defaults.get('init', None)
         post = post or self.apply_defaults.get('post', None)
@@ -633,7 +626,7 @@ class Batch(metaclass=MethodsTransformingMeta):
 
         # Compute result. Unbind the method to pass self explicitly
         parallel = inbatch_parallel(init=init, post=post, target=target, src=src, dst=dst)
-        transform = parallel(type(self)._apply_once)
+        transform = parallel(type(self)._apply_once)  # noqa: SLF001; private-member-access
         result = transform(self, *args, func=func, p=p, src=src, dst=dst,
                            apply_parallel_id=worker_ids, apply_parallel_seeds=rng_seeds, **kwargs)
         return result
@@ -816,7 +809,7 @@ class Batch(metaclass=MethodsTransformingMeta):
             components = tuple(dst or self.components)
             try:
                 item = tuple(data[i] for i in components)
-            except Exception as e:
+            except Exception as e: # noqa: BLE001, blind-except
                 raise KeyError('Cannot find components in corresponfig file', file_name) from e
         return item
 
@@ -887,9 +880,9 @@ class Batch(metaclass=MethodsTransformingMeta):
         if fmt == 'feather':
             feather.write_dataframe(_data, filename, *args, **kwargs)
         elif fmt == 'hdf5':
-            _data.to_hdf(filename, *args, **kwargs)   # pylint:disable=no-member
+            _data.to_hdf(filename, *args, **kwargs)
         elif fmt == 'csv':
-            _data.to_csv(filename, *args, **kwargs)   # pylint:disable=no-member
+            _data.to_csv(filename, *args, **kwargs)
         else:
             raise ValueError(f'Unknown format {fmt}')
 
