@@ -4,11 +4,15 @@ import warnings
 from numbers import Number
 
 import numpy as np
-import PIL
-import PIL.ImageOps
-import PIL.ImageChops
-import PIL.ImageFilter
-import PIL.ImageEnhance
+try:
+    import PIL
+    import PIL.ImageOps
+    import PIL.ImageChops
+    import PIL.ImageFilter
+    import PIL.ImageEnhance
+except ImportError:
+    pass
+
 from scipy.ndimage.filters import gaussian_filter
 from scipy.ndimage.interpolation import map_coordinates
 
@@ -343,10 +347,10 @@ class ImagesBatch(BaseImagesBatch):
                   f"sequence of floats in [0, 1) interval. Got {origin}"
             raise ValueError(msg)
 
-        return np.asarray(origin, dtype=np.int)
+        return np.asarray(origin, dtype=np.int64)
 
     @apply_parallel
-    def scale(self, image, factor, preserve_shape=False, origin='center', resample=0):
+    def scale(self, image, factor, preserve_shape=False, origin='center', resample=0, src=None, dst=None):
         """ Scale the content of each image in the batch.
 
         Resulting shape is obtained as original_shape * factor.
@@ -405,6 +409,8 @@ class ImagesBatch(BaseImagesBatch):
         -------
         self
         """
+        _ = src, dst
+
         original_shape = self._get_image_shape(image)
         rescaled_shape = list(np.int32(np.ceil(np.asarray(original_shape)*factor)))
         rescaled_image = image.resize(rescaled_shape, resample=resample)
@@ -413,7 +419,7 @@ class ImagesBatch(BaseImagesBatch):
         return rescaled_image
 
     @apply_parallel
-    def crop(self, image, origin, shape, crop_boundaries=False):
+    def crop(self, image, origin, shape, crop_boundaries=False, src=None, dst=None):
         """ Crop an image.
 
         Extract image data from the window of the size given by `shape` and placed at `origin`.
@@ -439,6 +445,8 @@ class ImagesBatch(BaseImagesBatch):
         element, as origin will be sampled independently for each `src` element.
         To randomly sample same origin for a number of components, use `R` named expression for `origin` argument.
         """
+        _ = src, dst
+
         origin = self._calc_origin(shape, origin, image.size)
         right_bottom = origin + shape
 
@@ -568,7 +576,7 @@ class ImagesBatch(BaseImagesBatch):
         return image.transform(*args, size=size, **kwargs)
 
     @apply_parallel
-    def resize(self, image, size, *args, **kwargs):
+    def resize(self, image, size, src=None, dst=None, *args, **kwargs):
         """ Calls ``image.resize(*args, **kwargs)``.
 
         For more details see `<https://pillow.readthedocs.io/en/stable/reference/Image.html#PIL.Image.Image.resize>_`.
@@ -585,6 +593,8 @@ class ImagesBatch(BaseImagesBatch):
         p : float
             Probability of applying the transform. Default is 1.
         """
+        _ = src, dst
+
         if size[0] is None and size[1] is None:
             raise ValueError('At least one component of the parameter "size" must be a number.')
         if size[0] is None:
@@ -597,7 +607,7 @@ class ImagesBatch(BaseImagesBatch):
         return image.resize(new_size, *args, **kwargs)
 
     @apply_parallel
-    def shift(self, image, offset, mode='const'):
+    def shift(self, image, offset, mode='const', src=None, dst=None):
         """ Shifts an image.
 
         Parameters
@@ -612,6 +622,8 @@ class ImagesBatch(BaseImagesBatch):
         p : float
             Probability of applying the transform. Default is 1.
         """
+        _ = src, dst
+
         if mode == 'const':
             image = image.transform(size=image.size,
                                     method=PIL.Image.AFFINE,
@@ -669,7 +681,7 @@ class ImagesBatch(BaseImagesBatch):
         return image.rotate(*args, **kwargs)
 
     @apply_parallel
-    def flip(self, image, mode='lr'):
+    def flip(self, image, mode='lr', src=None, dst=None):
         """ Flips image.
 
         Parameters
@@ -685,6 +697,8 @@ class ImagesBatch(BaseImagesBatch):
         p : float
             Probability of applying the transform. Default is 1.
         """
+        _ = src, dst
+
         if mode == 'lr':
             return PIL.ImageOps.mirror(image)
         return PIL.ImageOps.flip(image)
@@ -825,7 +839,7 @@ class ImagesBatch(BaseImagesBatch):
         return image
 
     @apply_parallel
-    def multiply(self, image, multiplier=1., clip=False, preserve_type=False):
+    def multiply(self, image, multiplier=1., clip=False, preserve_type=False, src=None, dst=None):
         """ Multiply each pixel by the given multiplier.
 
         Parameters
@@ -843,6 +857,8 @@ class ImagesBatch(BaseImagesBatch):
         p : float
             Probability of applying the transform. Default is 1.
         """
+        _ = src, dst
+
         multiplier = np.float32(multiplier)
         if isinstance(image, PIL.Image.Image):
             if preserve_type is False:
@@ -850,7 +866,7 @@ class ImagesBatch(BaseImagesBatch):
                               "stores data as `np.uint8`. To suppress this warning, use `preserve_type=True` or "
                               "consider using `to_array` action before multiplication.")
             return PIL.Image.fromarray(np.clip(multiplier*np.asarray(image), 0, 255).astype(np.uint8))
-        dtype = image.dtype if preserve_type else np.float
+        dtype = image.dtype if preserve_type else np.float32
         if clip:
             image = np.clip(multiplier*image, 0, 255 if dtype == np.uint8 else 1.)
         else:
@@ -879,7 +895,7 @@ class ImagesBatch(BaseImagesBatch):
         term = np.float32(term)
         if isinstance(image, PIL.Image.Image):
             return PIL.Image.fromarray(np.clip(term+np.asarray(image), 0, 255).astype(np.uint8))
-        dtype = image.dtype if preserve_type else np.float
+        dtype = image.dtype if preserve_type else np.float32
         if clip:
             image = np.clip(term+image, 0, 255 if dtype == np.uint8 else 1.)
         else:
