@@ -1,12 +1,13 @@
 """ Contains two class classification metrics """
+# ruff : noqa: E741; ambiguous-variable-name
+
 from copy import copy
 from functools import partial
 
 import numpy as np
+from numba import jit
 
-from ...decorators import mjit
 from . import Metrics, binarize, sigmoid, infmean
-from ...plotter import plot
 
 
 
@@ -181,11 +182,18 @@ class ClassificationMetrics(Metrics):
             'title': 'Normalized confusion matrix' if normalize else 'Confusion matrix',
             'xlabel': 'Actual class',
             'xtick_locations': np.arange(confusion_matrix.shape[0]),
+            'xtick_labels': classes,
+            'xtick_rotation': 90,
+            'xtick_ha': 'center',
             'ylabel': 'Predicted class',
             'ytick_locations': np.arange(confusion_matrix.shape[1]),
+            'ytick_labels': classes,
+            'ytick_rotation': 0,
+            'ytick_va': 'center',
             **kwargs
         }
 
+        from ...plotter import plot
         return plot(data=confusion_matrix, mode='matrix', **plot_config)
 
     def copy(self):
@@ -217,36 +225,23 @@ class ClassificationMetrics(Metrics):
 
     def append(self, metrics):
         """ Append confusion matrix with data from another metrics"""
-        # pylint: disable=protected-access
-        self._confusion_matrix = np.concatenate((self._confusion_matrix, metrics._confusion_matrix), axis=0)
+        self._confusion_matrix = np.concatenate((self._confusion_matrix, metrics._confusion_matrix), axis=0)  # noqa: SLF001; private-member-access
 
     def update(self, metrics):
         """ Update confusion matrix with data from another metrics"""
-        # pylint: disable=protected-access
         if self._no_zero_axis:
-            self._confusion_matrix = self._confusion_matrix + metrics._confusion_matrix
+            self._confusion_matrix = self._confusion_matrix + metrics._confusion_matrix  # noqa: SLF001; private-member-access
         else:
-            self._confusion_matrix = np.concatenate((self._confusion_matrix, metrics._confusion_matrix), axis=0)
+            self._confusion_matrix = np.concatenate((self._confusion_matrix, metrics._confusion_matrix), axis=0)  # noqa: SLF001; private-member-access
 
     def __getitem__(self, item):
-        # pylint: disable=protected-access
         metrics = self.copy()
-        metrics._confusion_matrix = metrics._confusion_matrix[item]
+        metrics._confusion_matrix = metrics._confusion_matrix[item]  # noqa: SLF001; private-member-access
         return metrics
 
     def _calc(self):
         self._confusion_matrix = np.zeros((self.targets.shape[0], self.num_classes, self.num_classes), dtype=np.intp)
-        return self._calc_confusion_jit(self.targets, self.predictions, self.num_classes, self._confusion_matrix)
-
-    @mjit
-    def _calc_confusion_jit(self, targets, predictions, num_classes, confusion):
-        for i in range(targets.shape[0]):
-            targ = targets[i].flatten()
-            pred = predictions[i].flatten()
-            for t in range(num_classes):
-                coords = np.where(targ == t)
-                for c in pred[coords]:
-                    confusion[i, c, t] += 1
+        return _calc_confusion_jit(self.targets, self.predictions, self.num_classes, self._confusion_matrix)
 
     def _return(self, value):
         return value[0] if isinstance(value, np.ndarray) and value.shape == (1, ) else value
@@ -380,3 +375,14 @@ class ClassificationMetrics(Metrics):
     def jaccard(self, *args, **kwargs):
         d = self.dice(*args, **kwargs)
         return np.nan_to_num(d / (2 - d), nan=np.inf)
+
+
+@jit(nopython=True, nogil=True)
+def _calc_confusion_jit(targets, predictions, num_classes, confusion):
+    for i in range(targets.shape[0]):
+        targ = targets[i].flatten()
+        pred = predictions[i].flatten()
+        for t in range(num_classes):
+            coords = np.where(targ == t)
+            for c in pred[coords]:
+                confusion[i, c, t] += 1
