@@ -1,12 +1,13 @@
 """ PyTorch custom layers. """
-# pylint: disable=wildcard-import
+
 from .multilayer import MultiLayer
 from .core import Flatten, Dense, DenseAlongAxis, Dropout, AlphaDropout
 from .activation import Activation, RadixSoftmax
 from .normalization import Normalization, LayerNorm
 from .conv import (Conv, ConvTranspose,
                    DepthwiseConv, DepthwiseConvTranspose, SeparableConv, SeparableConvTranspose)
-from .conv_complex import MultiKernelConv, SharedKernelConv, AvgPoolConv, BilinearConvTranspose, MultiScaleConv
+from .conv_complex import (MultiKernelConv, SharedKernelConv, AvgPoolConv, BilinearConvTranspose,
+                           MultiScaleConv, DeformableConv2d)
 from .pooling import MaxPool, AvgPool, GlobalMaxPool, GlobalAvgPool, ChannelPool
 from .resize import IncreaseDim, Reshape, Crop, Interpolate
 from .combine import Combine
