@@ -73,9 +73,11 @@ class Activation(nn.Module):
         Additional named arguments passed to either class initializer or callable.
     """
     FUNCTIONS = {f.lower(): f for f in dir(nn)}
-    FUNCTIONS['rsoftmax'] = RadixSoftmax
+    FUNCTIONS.update({
+        'rsoftmax': RadixSoftmax,
+    })
 
-    def __init__(self, activation, *args, **kwargs):
+    def __init__(self, activation='relu', *args, **kwargs):
         super().__init__()
         self.args, self.kwargs = tuple(), {}
 
