@@ -2,8 +2,8 @@
 import numpy as np
 
 import torch
-import torch.nn as nn
-import torch.nn.functional as F
+from torch import nn
+import torch.nn.functional as F # noqa: N812; lowercase-imported-as-non-lowercase
 
 
 
