@@ -1,7 +1,7 @@
 """ Losses that work with multiclass tasks. """
 import torch
-import torch.nn as nn
-import torch.nn.functional as F
+from torch import nn
+import torch.nn.functional as F # noqa: N812; lowercase-imported-as-non-lowercase
 
 
 
