@@ -2,7 +2,7 @@
 import numpy as np
 import torch
 from torch import nn
-
+import torch.nn.functional as F # noqa: N812; lowercase-imported-as-non-lowercase
 
 
 def to_n_tuple(value, n):
@@ -31,9 +31,8 @@ def safe_eval(expression, value, names=None):
     Increase number of channels of tensor by the factor of two::
     new_channels = safe_eval('same * 2', old_channels)
     """
-    #pylint: disable=eval-used
     names = names or ['S', 'same']
-    return eval(expression, {}, {name: value for name in names})
+    return eval(expression, {}, {name: value for name in names})  # noqa: S307; suspicious-eval-usage
 
 
 def make_initialization_inputs(inputs, device=None):
@@ -63,6 +62,18 @@ def get_shape(inputs, default_shape=None):
         raise TypeError(f'Inputs can be array, tensor, or sequence, got {type(inputs)} instead!')
     return shape
 
+def get_size(inputs):
+    """ Compute number of elements in tensor or in list of tensors """
+    if isinstance(inputs, np.ndarray):
+        size = inputs.size
+    elif isinstance(inputs, torch.Tensor):
+        size = inputs.numel()
+    elif isinstance(inputs, list):
+        size = [get_size(item) for item in inputs]
+    else:
+        raise TypeError(f'Inputs can be array, tensor, or sequence, got {type(inputs)} instead!')
+    return size
+
 def get_num_channels(inputs):
     """ Get number of channels in one tensor. """
     return inputs.shape[1]
@@ -87,14 +98,33 @@ def make_shallow_dict(module):
         - keys are valid attribute names for each children
         - values are submodules themselves, directly contained in torch.nn, e.g. nn.Conv2d, nn.Linear
     """
-    #pylint: disable=protected-access
     if module.__class__ is getattr(nn, module.__class__.__name__, None):
         return {None : module}
 
     result = {}
-    for key, value in module._modules.items():
+    for key, value in module._modules.items():  # noqa: SLF001; private-member-access
         subdict = make_shallow_dict(value)
         for subkey, subvalue in subdict.items():
             store_key = f'{key}/{subkey}' if subkey is not None else key
             result[store_key] = subvalue
     return result
+
+def pad(inputs, spatial_shape, target_shape):
+    """ Pad spatial dimensions of a tensor to a target shape. """
+    pad_values = [0] * len(spatial_shape) * 2
+    pad_dims = np.nonzero(np.array(spatial_shape) < np.array(target_shape))[0]
+    for dim in pad_dims:
+        pad_values[dim * 2] = (target_shape[dim] - spatial_shape[dim]) // 2
+        pad_values[dim * 2 + 1] = (target_shape[dim] - spatial_shape[dim] + 1) // 2
+    padded_inputs = F.pad(inputs, pad_values[::-1])
+    return padded_inputs
+
+def center_crop(inputs, target_shape, dims):
+    """ Crop last dims of a tensor at the center. """
+    inputs_shape = np.array(get_shape(inputs))
+    to_crop_shape = inputs_shape[-dims:]
+    no_crop_shape = inputs_shape[:-dims]
+    crop_lefts = (to_crop_shape - target_shape) // 2
+    crops_ = [slice(crop_lefts[i], crop_lefts[i] + target_shape[i]) for i in range(dims)]
+    crops = [slice(dim) for dim in no_crop_shape] + crops_
+    return inputs[crops]
