@@ -19,15 +19,12 @@ except ImportError:
 
 from .named_expr import NamedExpression, eval_expr
 from .monitor import ResourceMonitor, MONITOR_ALIASES
-from .utils_telegram import TelegramMessage
-from .plotter import plot
-from .plotter.utils import PlotConfig
+
 
 
 
 class DummyBar:
     """ Progress tracker without visual representation. """
-    #pylint: disable=invalid-name
     def __init__(self, total, *args, **kwargs):
         self.total = total
         self.args, self.kwargs = args, kwargs
@@ -94,6 +91,7 @@ class Notifier:
         If str, then either registered monitor identifiers or names of pipeline variables.
         Named expressions are evaluated with the pipeline.
         If callable, then it is used to retrieve the container with data.
+        Should accept variable named arguments in the signature and may return ``None`` value to disable its plotting.
         If sequence, then it is used as the container with data.
         If dict, then 'source' key should be one of the above to identify container.
         Other available keys:
@@ -128,7 +126,6 @@ class Notifier:
     *args, **kwargs
         Positional and keyword arguments that are used to create underlying progress bar.
     """
-    #pylint: disable=too-many-arguments
     COLOUR_RUNNING = '#2196f3'
     COLOUR_SUCCESS = '#4caf50'
     COLOUR_FAILURE = '#f44336'
@@ -182,7 +179,7 @@ class Notifier:
                 elif isinstance(source, str):
                     container['name'] = source
                 elif callable(source):
-                    container['name'] = '<unknown_callable>'
+                    container['name'] = source.__name__
                 else:
                     container['name'] = '<unknown_container>'
 
@@ -224,7 +221,7 @@ class Notifier:
             if bar_func is tqdm:
                 ncols = min(80 + 10 * self.n_monitors, 120)
                 colour = self.COLOUR_SUCCESS
-            elif bar_func is tqdm_notebook:
+            else:
                 ncols = min(700 + 150 * self.n_monitors, 1000)
                 colour = None
 
@@ -238,6 +235,7 @@ class Notifier:
         # Function to initialize / reinitialize bar, when needed
         if disable:
             bar_func = DummyBar
+            self.bar = None
             self.disable()
 
         self.bar = None
@@ -250,13 +248,14 @@ class Notifier:
         self.make_bar()
 
         # Prepare plot params
-        #pylint: disable=invalid-unary-operand-type
         self.slice = slice(-window, None, None) if isinstance(window, int) else slice(None)
         self.savepath = savepath
 
         # Prepare Telegram notifications
         self.telegram = telegram
         if self.telegram or initialize_telegram:
+            from .utils_telegram import TelegramMessage
+
             self.telegram_text = TelegramMessage(token=token, chat_id=chat_id, silent=silent)
             self.telegram_media = TelegramMessage(token=token, chat_id=chat_id, silent=silent)
 
@@ -278,7 +277,8 @@ class Notifier:
         if self.bar is not None:
             try:
                 # jupyter bar must be closed and reopened
-                self.bar.display(close=True)
+                if not getattr(self.bar, 'disable', False):
+                    self.bar.display(close=True)
                 self.bar = self.bar_func(total=self.total)
             except TypeError:
                 # text bar can work with a simple reassigning of `total`
@@ -363,7 +363,7 @@ class Notifier:
                 container['data'] = value
 
             elif callable(source):
-                container['data'] = source()
+                container['data'] = source(container=container, notifier=self, pipeline=pipeline, batch=batch)
 
             else:
                 raise TypeError(f'Unknown type of `source`, {type(source)}!')
@@ -373,14 +373,15 @@ class Notifier:
         """ Set the new bar description, if needed. """
         postfix = self.create_description(iteration=-1)
 
-        previous_postfix = self.bar.postfix or ''
+        previous_postfix = getattr(self.bar, 'postfix', None) or ''
         if postfix and not previous_postfix.startswith(postfix):
             self.bar.set_postfix_str(postfix)
 
     def make_plotter(self, num_graphs=None, layout='horizontal', figsize=None, ncols=None, nrows=None, **kwargs):
         """ Make canvas for plotting graphs. """
+        from .plotter import plot
         if num_graphs is None:
-            num_graphs = len(self.data_containers)
+            num_graphs = sum(container['data'] is not None for container in self.data_containers)
 
         if ncols is None and nrows is None:
             if layout in ['h', 'horizontal']:
@@ -412,6 +413,7 @@ class Notifier:
     def update_plot(self, index=0, add_suptitle=False, savepath=None, clear_display=True, show=True,
                     telegram=None, **kwargs):
         """ Draw plots anew. """
+        from .plotter.utils import PlotConfig
         plot_config = PlotConfig(kwargs)
 
         if clear_display:
@@ -427,7 +429,8 @@ class Notifier:
             self.plotter.config['suptitle'] = self.bar.format_meter(**fmt)
             self.plotter.annotate()
 
-        for i, container in enumerate(self.data_containers):
+        data_containers = [container for container in self.data_containers if container['data'] is not None]
+        for i, container in enumerate(data_containers):
             if i >= index:
                 subplot_index = i - index
                 subplot_config = plot_config.maybe_index(subplot_index)
@@ -456,14 +459,20 @@ class Notifier:
         name = container['name']
         plot_function = container.get('plot_function')
         plot_config = container.get('plot_config', {})
-        x = np.arange(len(data))[self.slice]
-        y = np.array(data)[self.slice]
+        plot_config = {**plot_config, **kwargs}
+
+        x = np.arange(len(data)) if hasattr(data, '__len__') else None
+        y = data
+        if self.slice not in [None, slice(None)]:
+            x = np.array(x)[self.slice]
+            y = np.array(y)[self.slice]
 
         if plot_function is not None:
-            plot_function(ax=subplot.ax, index=index, x=x, y=y, container=container, notifier=self, **kwargs)
+            plot_function(ax=subplot.ax, index=index, x=x, y=y, container=container, notifier=self, **plot_config)
         elif isinstance(source, ResourceMonitor):
-            plot_config = {**plot_config, **kwargs}
             source.plot(plotter=self.plotter, positions=index, **plot_config)
+        elif data is None:
+            pass
         else:
             source_defaults = {'title': name}
             if isinstance(data, (tuple, list)) or (isinstance(data, np.ndarray) and data.ndim == 1):
@@ -487,7 +496,7 @@ class Notifier:
                     msg += f" Got {type(data)} instead."
                 raise ValueError(msg)
 
-            plot_config = {**source_defaults, **plot_config, **kwargs}
+            plot_config = {**source_defaults, **plot_config}
             self.plotter.plot(data=data, mode=mode, positions=index, **plot_config)
 
     def update_log_file(self):
@@ -538,7 +547,7 @@ class Notifier:
                 yield item
                 self.update()
             self.close(success=True)
-        except: #pylint: disable=bare-except
+        except:
             self.close(success=False)
             raise
 
@@ -551,7 +560,6 @@ class Notifier:
 
     def close(self, success=True):
         """ Close the underlying progress bar. """
-        #pylint: disable=attribute-defined-outside-init
         if not success:
             self.bar.colour = self.COLOUR_FAILURE
 
@@ -622,8 +630,7 @@ class Notifier:
     @staticmethod
     def clear():
         """ Clear all the instances. Can help fix tqdm behaviour. """
-        # pylint: disable=protected-access
-        tqdm._instances.clear()
+        tqdm._instances.clear()  # noqa: SLF001; private-member-access
 
 
 def notifier(iterable, *args, bar='a', **kwargs):
