@@ -42,7 +42,7 @@ class BaseCOCO(ImagesOpenset):
         filename = basename(url)
         localname = os.path.join(path, filename)
         if not os.path.isfile(localname):
-            r = requests.get(url, stream=True)
+            r = requests.get(url, stream=True, headers={"User-Agent": "XY"}, timeout=10)
             file_size = int(r.headers['Content-Length'])
             chunk_size = 1024 * 1000 #MBs
             num_bars = int(file_size / chunk_size)
@@ -52,6 +52,7 @@ class BaseCOCO(ImagesOpenset):
                                        unit='MB', desc=filename, leave=True, disable=self.disable_tqdm):
                     f.write(chunk)
 
+
         folder_to_extract = os.path.join(dirname(localname), content)
         #check that root folder from the archive already exists to avoid extracting, as its time consuming
         path_to_extracted = os.path.join(folder_to_extract, train_val)
@@ -92,7 +93,7 @@ class COCOSegmentation(BaseCOCO):
     def _post_fn(self, all_res, *args, **kwargs):
         _ = args, kwargs
         if any_action_failed(all_res):
-            raise IOError('Could not download files:', all_res)
+            raise OSError('Could not download files:', all_res)
 
         if self.drop_grayscale:
             train_index = FilesIndex(path=self._rgb_images_paths(all_res[0]), no_ext=True)
