@@ -1,4 +1,5 @@
 """ Contains PascalVOC dataset and labels for different tasks """
+# ruff : noqa : S310; suspicious-url-open-usage
 
 import os
 from os.path import dirname, basename
@@ -41,7 +42,7 @@ class BasePascal(ImagesOpenset):
         super().__init__(*args, preloaded=preloaded, train_test=train_test, **kwargs)
         if unpack:
             with tarfile.open((self.localname), "r") as archive:
-                archive.extractall(dirname(self.localname))
+                archive.extractall(dirname(self.localname)) # noqa: S202; tarfile-unsafe-members
 
     def download_archive(self, path=None):
         """ Download archive"""
@@ -52,7 +53,7 @@ class BasePascal(ImagesOpenset):
         self.localname = localname
 
         if not os.path.isfile(localname):
-            r = requests.get(self.SOURCE_URL, stream=True)
+            r = requests.get(self.SOURCE_URL, stream=True, timeout=10)
             file_size = int(r.headers['Content-Length'])
             chunk = 1
             chunk_size = 1024
@@ -92,6 +93,7 @@ class PascalSegmentation(BasePascal):
     classes = ['background', 'aeroplane', 'bicycle', 'bird', 'boat', 'bottle', 'bus', 'car', 'cat', 'chair',
                'cow', 'dining table', 'dog', 'horse', 'motorbike', 'person', 'potted plant', 'sheep', 'sofa',
                'train', 'TV/monitor']
+    num_classes = len(classes)
 
     def _mask_path(self, name):
         """ Return the path in the archive to the mask which is .png image by its name"""
