@@ -89,7 +89,7 @@ class PipelineExecutor:
             except StopPipeline:
                 batch = END_PIPELINE_SIGNAL
                 break
-            except Exception as exc:   # pylint: disable=broad-except
+            except Exception as exc: # noqa: BLE001, blind-except
                 print("Exception:", exc)
                 traceback.print_tb(exc.__traceback__)
                 if ignore_exceptions:
@@ -99,6 +99,8 @@ class PipelineExecutor:
             finally:
                 self._prefetch_queue.task_done()
                 self._batch_queue.put(batch, block=True)
+                if batch == END_PIPELINE_SIGNAL:
+                    self._stop_flag = True
 
 
     def gen_batch(self, *args, dataset=None, rebatch=False, reset='iter', profile=False,
@@ -167,8 +169,11 @@ class PipelineExecutor:
 
         if prefetch > 0:
 
-            if target in ['threads', 't']:
-                self._executor = cf.ThreadPoolExecutor(max_workers=prefetch + 1)
+            if isinstance(target, cf.Executor):
+                self._executor = target
+            elif target in ['threads', 't']:
+                self._executor = cf.ThreadPoolExecutor(max_workers=prefetch + 1,
+                                                       thread_name_prefix='BatchFlow-PipelineExecutor')
             elif target in ['mpc', 'm']:
                 self._executor = cf.ProcessPoolExecutor(max_workers=prefetch + 1)
             else:
@@ -186,19 +191,18 @@ class PipelineExecutor:
             # due to count queue both prefetch and batch queue cannot contain more than prefetch+1 items
 
             # service executor runs batch generation and batch processing threads
-            self._service_executor = cf.ThreadPoolExecutor(max_workers=2)
+            self._service_executor = cf.ThreadPoolExecutor(max_workers=2,
+                                                           thread_name_prefix='BatchFlow-PipelineServiceExecutor')
             # this thread submits batches (waits for count queue and puts into prefetch queue)
             self._service_executor.submit(self._put_batches_into_queue, batch_generator, seed=execution_seed)
             # this thread gets processed batches (waits for futures to be complete and puts into batch queue)
             self._service_executor.submit(self._run_batches_from_queue, ignore_exceptions)
 
             # main thread gets ready batches and yield them one by one (releasing count queue after each one)
-            while not self._stop_flag:
+            while not self._stop_flag or not self._batch_queue.empty():
                 batch_res = self._batch_queue.get(block=True)
                 self._batch_queue.task_done()
-                if batch_res == END_PIPELINE_SIGNAL:
-                    self._stop_flag = True
-                else:
+                if batch_res != END_PIPELINE_SIGNAL:
                     # the batch has been created in another thread, so we need to set pipeline
                     if batch_res is not None:
                         batch_res.pipeline = self.pipeline
@@ -207,6 +211,10 @@ class PipelineExecutor:
                     self._prefetch_count.get(block=True)
                     self._prefetch_count.task_done()
 
+            if self._executor != target:
+                self._executor.shutdown()
+            self._service_executor.shutdown()
+
         else:
             # save RNG
             random = self.pipeline.random
@@ -224,7 +232,7 @@ class PipelineExecutor:
                 except KeyboardInterrupt:
                     notifier.close(success=False)
                     raise
-                except Exception as exc:  # pylint:disable=broad-except
+                except Exception as exc: # noqa: BLE001, blind-except
                     if ignore_exceptions:
                         print("Exception:", exc)
                         traceback.print_tb(exc.__traceback__)
