@@ -4,13 +4,16 @@ import os
 import functools
 from collections import OrderedDict
 import glob
+
 import multiprocess as mp
-import pandas as pd
 import numpy as np
 
 from ..utils import to_list
 from .utils import deserialize
 
+from ..utils_import import make_delayed_import
+pd = make_delayed_import('pandas')
+
 class ResearchResults:
     """ Class to collect, load and process research results.
 
@@ -29,7 +32,7 @@ class ResearchResults:
         self._manager = mp.Manager()
         self.results = self._manager.dict()
         self.configs = self._manager.dict()
-        self.artifacts = dict()
+        self.artifacts = {}
         self.kwargs = kwargs
 
         if dump_results and os.path.exists(name):
@@ -80,7 +83,7 @@ class ResearchResults:
             is used as `config`. If `config` is not defined but `alias` is, then will be concated to `alias`.
         """
         experiment_id, name, iterations = self.filter(experiment_id, name, iterations, config, alias, domain, **kwargs)
-        results = dict()
+        results = {}
         for path in glob.glob(os.path.join(self.name, 'experiments', '*', 'results', '*')):
             path = os.path.normpath(path)
             _experiment_id, _, _name = path.split(os.sep)[-3:]
@@ -116,7 +119,7 @@ class ResearchResults:
         kwargs : dict
             is used as `config`. If `config` is not defined but `alias` is, then will be concated to `alias`.
         """
-        self.artifacts = dict()
+        self.artifacts = {}
         names = to_list('*' if name is None else name)
         experiment_id, _, _ = self.filter(experiment_id, None, None, config, alias, domain, **kwargs)
         for _name in names:
@@ -168,7 +171,7 @@ class ResearchResults:
         """ Create pandas.DataFrame from results. """
         return self.to_df()
 
-    def to_df(self, pivot=True, include_config=True, use_alias=False, concat_config=False,
+    def to_df(self, pivot=True, include_config=True, use_alias=True, concat_config=False,
               remove_auxilary=True, drop_columns=True, **kwargs):
         """ Create pandas.DataFrame from filtered results.
 
@@ -241,7 +244,7 @@ class ResearchResults:
             files_to_load = {int(os.path.basename(filename)): filename for filename in filenames}
         else:
             dumped_iteration = np.sort(np.array([int(os.path.basename(filename)) for filename in filenames]))
-            files_to_load = dict()
+            files_to_load = {}
             for iteration in iterations:
                 _it = dumped_iteration[np.argwhere(dumped_iteration >= iteration)[0, 0]]
                 files_to_load[_it] = os.path.join(path, str(_it))
@@ -328,8 +331,7 @@ class ResearchResults:
             self.load_configs()
             self.load_artifacts(**kwargs)
             df = []
-            for experiment_id in self.artifacts:
-                artifacts = self.artifacts[experiment_id]
+            for experiment_id, artifacts in self.artifacts.items():
                 df += [pd.DataFrame({'id': [experiment_id], **artifact}) for artifact in artifacts]
             if len(df) > 0:
                 df = pd.concat(df)
