@@ -1,16 +1,15 @@
 """ Tests for Research and correspong classes. """
-# pylint: disable=no-name-in-module, missing-docstring, redefined-outer-name
 import os
 import sys
 import glob
-from contextlib import ExitStack as does_not_raise
+from contextlib import ExitStack as does_not_raise # noqa: N813; camelcase-imported-as-lowercase
 import pytest
 import psutil
 
 import numpy as np
 
 from batchflow import Dataset, Pipeline, B, V, C
-from batchflow import NumpySampler as NS
+from batchflow import NumpySampler as NS # noqa: N817; camelcase-imported-as-acronym
 from batchflow.models.torch import ResNet
 from batchflow.opensets import CIFAR10
 from batchflow.research import Experiment, Executor, Domain, Option, Research, E, EC, O, S, ResearchResults, Alias
@@ -100,11 +99,11 @@ class TestDomain:
     @pytest.mark.parametrize('b', [[2, 3, 4]])
     @pytest.mark.parametrize('n_reps', [1, 2])
     def test_operations(self, op, a, b, n_reps):
-        option_1 = Domain({'a': a}) #pylint:disable=unused-variable
-        option_2 = Domain(b=b) #pylint:disable=unused-variable
+        option_1 = Domain({'a': a}) # noqa: F841; unused-variable
+        option_2 = Domain(b=b) # noqa: F841; unused-variable
 
         if not (op == '@' and len(a) != len(b)):
-            domain = eval(f'option_1 {op} option_2') # pylint:disable=eval-used
+            domain = eval(f'option_1 {op} option_2') # noqa: S307; suspicious-eval-usage
             domain.set_iter_params(n_reps=n_reps)
 
             configs = list(domain.iterator)
@@ -197,7 +196,7 @@ class TestExecutor:
 
         assert executor.experiments[0].results['sum'][0] == sum(range(10))
 
-    def test_direct_generator(self, generator): #pylint: disable=unused-argument
+    def test_direct_generator(self, generator):
         experiment = (Experiment()
             .add_namespace(locals())
             .generator(10, mode='generator')
@@ -516,7 +515,7 @@ class TestResearch:
             parsed_id = research.results.df.id.apply(lambda x: x.split('_'))
 
             # check the number of digits for each prefix code
-            assert parsed_id.apply(lambda x: all([len(i) == create_id_prefix for i in x[:-1]])).all()
+            assert parsed_id.apply(lambda x: all(len(i) == create_id_prefix for i in x[:-1])).all()
 
 
     def test_remove(self, simple_research):
@@ -537,7 +536,7 @@ class TestResearch:
             research = Research().add_callable(func)
             research.run(dump_results=False, executor_target='f', parallel=False, debug=debug)
 
-    @pytest.mark.parametrize('profile, shape', list(zip([2, 1], [9, 6])))
+    @pytest.mark.parametrize('profile, shape', list(zip([2, 1], [10, 5])))
     def test_profile(self, profile, shape, simple_research):
         simple_research.run(n_iters=3, dump_results=False, profile=profile)
 
@@ -548,12 +547,12 @@ class TestResearch:
         path = os.path.join(tmp_path, 'research')
         simple_research.run(name=path, n_iters=3, dump_results=True, loglevel=loglevel)
 
-        with open(os.path.join(path, 'research.log')) as file:
+        with open(os.path.join(path, 'research.log'), encoding='utf-8') as file:
             lines = file.readlines()
             assert len(lines) == length_res
 
         for path in glob.glob(os.path.join(path, 'experiments', '*')):
-            with open(os.path.join(path, 'experiment.log')) as file:
+            with open(os.path.join(path, 'experiment.log'), encoding='utf-8') as file:
                 lines = file.readlines()
                 assert len(lines) == length_exp
 
@@ -571,6 +570,7 @@ class TestResearch:
         assert research.results.df.iloc[0].a == f(2)
         assert research.results.df.iloc[0].b == f(3)
 
+    @pytest.mark.slow
     @pytest.mark.parametrize('dump_results', [False, True])
     @pytest.mark.parametrize('redirect_stdout', [True, 0, 1, 2, 3])
     @pytest.mark.parametrize('redirect_stderr', [True, 0, 1, 2, 3])
@@ -610,7 +610,7 @@ class TestResearch:
 
                 if param in [True, 1, 3]:
                     if dump_results:
-                        with open(os.path.join(research.name, filename)) as file:
+                        with open(os.path.join(research.name, filename), encoding='utf-8') as file:
                             lines = ''.join(file.readlines())
                     else:
                         lines = list(getattr(research.storage, 'experiments_'+name).values())[0]
@@ -618,7 +618,7 @@ class TestResearch:
 
                 if dump_results and param in [2, 3]:
                     for full_path in research.results.artifacts_to_df(name=filename)['full_path']:
-                        with open(full_path) as file:
+                        with open(full_path, encoding='utf-8') as file:
                             lines = ''.join(file.readlines())
                             assert lines == output * 2
 
