@@ -1,14 +1,10 @@
 """ A class to send updateable content messages to Telegram. """
 import os
 import json
-import imghdr
 from uuid import uuid4
 from io import BytesIO
 from concurrent.futures import ThreadPoolExecutor
 
-from urllib3 import PoolManager
-
-
 
 class TelegramMessage:
     """ Class to send a message with text or image (either a matplotlib figure or path to photo) to a Telegram bot.
@@ -28,6 +24,11 @@ class TelegramMessage:
     USER_AGENT = 'Python Telegram Bot (https://github.com/python-telegram-bot/python-telegram-bot)'
 
     def __init__(self, token=None, chat_id=None, silent=True, content=None):
+        try:
+            from urllib3 import PoolManager
+        except ImportError as e:
+            raise ImportError("urllib3 is missing. Install batchflow[telegram]") from e
+
         # Connection
         self.token = token or os.getenv('TELEGRAM_TOKEN')
         self.chat_id = chat_id or os.getenv('TELEGRAM_CHAT_ID')
@@ -66,7 +67,7 @@ class TelegramMessage:
         try:
             waiting = self.pool.submit(function, *args, **kwargs)
             self.queue.append(waiting)
-        except Exception as e: #pylint: disable=broad-except
+        except Exception as e: # noqa: BLE001, blind-except
             print(e)
 
 
@@ -146,6 +147,8 @@ class TelegramMessage:
     def content_to_dict(content, group=True, **kwargs):
         """ Convert a content (either a path to photo or matplotlib figure) to a telegram-acceptable dictionary. """
         # Convert content to a bytestring
+        from PIL import Image
+
         if isinstance(content, str):
             bytes_ = TelegramMessage.path_to_bytes(content)
         else:
@@ -153,7 +156,8 @@ class TelegramMessage:
 
         # Create unique id of attachment, pack entities in json
         attach_id = f'attached{uuid4().hex}'
-        attach_fmt = imghdr.what(None, bytes_)
+        image = Image.open(BytesIO(bytes_))
+        attach_fmt = image.format.lower()
 
         media_dict = {'media': f'attach://{attach_id}', 'type': 'photo'}
         media_dict = [media_dict] if group else media_dict
